@@ -11,7 +11,7 @@ use Readonly;
 
 Readonly::Array our @FORM_METHODS => qw(post get);
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 # Constructor.
 sub new {
@@ -436,6 +436,43 @@ Returns undef.
  #   </fieldset>
  # </form>
 
+=head1 EXAMPLE2
+
+=for comment filename=plack_app_login_access.pl
+
+ use strict;
+ use warnings;
+ 
+ use CSS::Struct::Output::Indent;
+ use Plack::App::Tags::HTML;
+ use Plack::Runner;
+ use Tags::Output::Indent;
+ use Unicode::UTF8 qw(decode_utf8);
+ 
+ my $app = Plack::App::Tags::HTML->new(
+         'component' => 'Tags::HTML::Login::Access',
+         'constructor_args' => {
+                 'register_url' => '/register',
+         },
+         'css' => CSS::Struct::Output::Indent->new,
+         'tags' => Tags::Output::Indent->new(
+                 'xml' => 1,
+                 'preserved' => ['style'],
+         ),
+         'title' => 'Login and password',
+ )->to_app;
+ Plack::Runner->new->run($app);
+
+ # Output screenshot is in images/ directory.
+
+=begin html
+
+<a href="https://raw.githubusercontent.com/michal-josef-spacek/Tags-HTML-Login-Access/master/images/plack_app_login_access.png">
+  <img src="https://raw.githubusercontent.com/michal-josef-spacek/Tags-HTML-Login-Access/master/images/plack_app_login_access.png" alt="Web app example" width="300px" height="300px" />
+</a>
+
+=end html
+
 =head1 DEPENDENCIES
 
 L<Class::Utils>,
@@ -472,6 +509,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
